@@ -39,6 +39,8 @@ class InstanceType(Enum):
     IMAGE = "image"
     HIGHCHART = "highchart"
     DATATABLE = "data_table"
+    IFRAME = "iframe"
+    CUSTOM_HTML="custom_html"
 
 class BoxData(BaseUpdate):
     icon: str
@@ -151,8 +153,9 @@ class ReactiveData(BaseUpdate):
     hidden: bool = False
 
 class DownloadData(BaseUpdate):
-    file_name: str
+    label: str
     url: str
+    name: str
 
 class ImageData(BaseUpdate):
     url: str
@@ -168,6 +171,24 @@ class UploadData(BaseUpdate):
 class HighChartData(BaseUpdate):
     config: Dict
 
+class IframeData(BaseUpdate):
+    url: str
+    width: str = "1100"
+    height: str = "400"
+
+class ToolTipData(BaseUpdate):
+    label: str = ''
+
+class DialogBox(BaseUpdate):
+    url: str = ''
+    height: str = '60%'
+    width: str = '60%'
+
+class CustomHTML(BaseUpdate):
+    name: str
+    html: str
+    full_custom: bool = False
+    script: Optional[str]
 
 
 class ReturnData(BaseUpdate):
@@ -204,10 +225,13 @@ class ReturnData(BaseUpdate):
     upload_data: Optional[UploadData]
     image_data: Optional[ImageData]
     highchart_data: Optional[HighChartData]
-
+    iframe_data: Optional[IframeData]
+    custom_html_data: Optional[CustomHTML]
     footer: Optional[str]
     flex: Optional[FlexData] = FlexData()
     reactive: Optional[ReactiveData] = ReactiveData()
+    tooltip_data: Optional[ToolTipData]
+    dialog_data: Optional[DialogBox]
 
 class UpdateInstanceType(Enum):
     """ Docstring for class UpdateInstanceType
